#!/bin/sh
set -e

SCRIPT_DIR=$(realpath `dirname "$0"`)


. $SCRIPT_DIR/download_boot_systems.sh

download_debian_11_if_needed
download_sysrescuecd_if_needed

#UPDATE THOSE VARIABLES DEPENDING ON YOUR SITE
MY_IF_NAME=eth0
MY_IP_ADDR=192.168.46.2
DHCP_RANGE=192.168.46.100,static,255.255.255.0
ROUTER_ADDR=192.168.46.2
DNS_SERVER=1.1.1.1

#This is to make linux output visible in IPMI SOL. Remove if you are using a graphical card.
common=console=ttyS1,57600

mac='
00:22:4d:dd:64:38
00:22:4d:dd:65:34
00:22:4d:dd:64:c4
00:22:4d:dd:64:cc
00:22:4d:dd:64:84
00:22:4d:dd:65:40
00:22:4d:dd:64:5a
00:22:4d:dd:65:36
00:22:4d:dd:64:2c
00:22:4d:dd:64:b6
00:22:4d:dd:65:08
00:22:4d:dd:64:70
00:22:4d:dd:64:ca
00:22:4d:dd:64:d8
00:22:4d:dd:64:fe
'
i=1
hostname_prefix=douai-capri-

(
#echo set timeout=0
echo if false
echo then true
for mac in $mac; do
  echo "elif [ \$net_default_mac = $mac ]"
  echo then set i=`printf %03u $i`
  i=`expr $i + 1`
done
cat <<EOF
else unset timeout
fi

menuentry 'Install Debian' {
  linux /debian-installer/amd64/linux vga=788 url=tftp://\$pxe_default_server/preseed.cfg language=C country=FR keymap=fr hostname=${hostname_prefix}\$i domain= --- mitigations=off $common
  initrd /debian-installer/amd64/initrd.gz
}
menuentry 'SystemRescueCd' {
  linux /sysresccd/sysresccd/boot/x86_64/vmlinuz archisobasedir=sysresccd archiso_http_srv=http://\$pxe_default_server:69/sysresccd/ checksum ip=dhcp $common
  initrd /sysresccd/sysresccd/boot/intel_ucode.img /sysresccd/sysresccd/boot/amd_ucode.img /sysresccd/sysresccd/boot/x86_64/sysresccd.img
}
menuentry 'Exit' {
  exit
}
EOF
) >debian-installer/amd64/grub/grub.cfg


for mac in $mac
do
  hostname=${hostname_prefix}$(printf %03u $i)
  mkdir -p $hostname
  cat > $hostname/interfaces <<EOF
# This file describes the network interfaces available on your system
# and how to activate them. For more information, see interfaces(5).

source /etc/network/interfaces.d/*

# The loopback network interface
auto lo
iface lo inet loopback

# The primary network interface
allow-hotplug eno1
#iface eno1 inet dhcp
iface eno1 inet static
  address 192.168.46.$(( 50 + $i ))/24

# name for older Linux kernel
allow-hotplug enp193s0f1
iface enp193s0f1 inet static
  address 195.90.118.$(( 194 + $i ))/27
  gateway 195.90.118.193
  dns-nameservers 1.1.1.1 8.8.8.8

# name for newest Linux kernel (>= 5.10)
allow-hotplug enp193s0f1np1
iface enp193s0f1np1 inet static
  address 195.90.118.$(( 194 + $i ))/27
  gateway 195.90.118.193
  dns-nameservers 1.1.1.1 8.8.8.8

#allow-hotplug enp193s0f0
#iface enp193s0f0 inet dhcp

EOF
  i=`expr $i + 1`
done

exec dnsmasq -d --port=0 --log-dhcp \
  --interface=$MY_IF_NAME \
  --bind-interfaces \
  --except-interface=lo \
  --listen-address=$MY_IP_ADDR \
  --dhcp-range=$DHCP_RANGE \
  --dhcp-option=option:router,$ROUTER_ADDR \
  --dhcp-option=option:dns-server,$DNS_SERVER \
  --dhcp-boot=debian-installer/amd64/grubx64.efi \
  --enable-tftp --tftp-root=$(realpath `dirname "$0"`) \
  --conf-file=/dev/null \
  --dhcp-host=00:22:4D:DD:64:38,192.168.46.51,1h \
  --dhcp-host=00:22:4D:DD:65:34,192.168.46.52,1h \
  --dhcp-host=00:22:4D:DD:64:C4,192.168.46.53,1h \
  --dhcp-host=00:22:4D:DD:64:CC,192.168.46.54,1h \
  --dhcp-host=00:22:4D:DD:64:84,192.168.46.55,1h \
  --dhcp-host=00:22:4D:DD:65:40,192.168.46.56,1h \
  --dhcp-host=00:22:4D:DD:64:5A,192.168.46.57,1h \
  --dhcp-host=00:22:4D:DD:65:36,192.168.46.58,1h \
  --dhcp-host=00:22:4D:DD:64:2C,192.168.46.59,1h \
  --dhcp-host=00:22:4D:DD:64:B6,192.168.46.60,1h \
  --dhcp-host=00:22:4D:DD:65:08,192.168.46.61,1h \
  --dhcp-host=00:22:4D:DD:64:70,192.168.46.62,1h \
  --dhcp-host=00:22:4D:DD:64:CA,192.168.46.63,1h \
  --dhcp-host=00:22:4D:DD:64:D8,192.168.46.64,1h \
  --dhcp-host=00:22:4D:DD:64:FE,192.168.46.65,1h \
  --dhcp-host=00:22:4D:DD:64:39,192.168.46.101,1h \
  --dhcp-host=00:22:4D:DD:65:35,192.168.46.102,1h \
  --dhcp-host=00:22:4D:DD:64:C5,192.168.46.103,1h \
  --dhcp-host=00:22:4D:DD:64:CD,192.168.46.104,1h \
  --dhcp-host=00:22:4D:DD:64:85,192.168.46.105,1h \
  --dhcp-host=00:22:4D:DD:65:41,192.168.46.106,1h \
  --dhcp-host=00:22:4D:DD:64:5B,192.168.46.107,1h \
  --dhcp-host=00:22:4D:DD:65:37,192.168.46.108,1h \
  --dhcp-host=00:22:4D:DD:64:2D,192.168.46.109,1h \
  --dhcp-host=00:22:4D:DD:64:B7,192.168.46.110,1h \
  --dhcp-host=00:22:4D:DD:65:09,192.168.46.111,1h \
  --dhcp-host=00:22:4D:DD:64:71,192.168.46.112,1h \
  --dhcp-host=00:22:4D:DD:64:CB,192.168.46.113,1h \
  --dhcp-host=00:22:4D:DD:64:D9,192.168.46.114,1h \
  --dhcp-host=00:22:4D:DD:64:FF,192.168.46.115,1h \

