#!/bin/sh
set -e

SCRIPT_DIR=$(realpath `dirname "$0"`)


. $SCRIPT_DIR/download_boot_systems.sh

download_debian_11_if_needed
download_ubuntu_20_if_needed
#download_sysrescuecd_if_needed

#UPDATE THOSE VARIABLES DEPENDING ON YOUR SITE
MY_IF_NAME=eth0
MY_IP_ADDR=192.168.46.2
DHCP_RANGE=192.168.46.100,static,255.255.255.0
ROUTER_ADDR=192.168.46.2
DNS_SERVER=8.8.8.8

(
cat <<EOF
if [ \$net_default_mac = 7c:fe:90:43:80:a6 ];
then
  set hostname=lille-edu-leopard-000
  set interface=eno1
elif [ \$net_default_mac = 00:22:4d:d9:0a:aa ];
then 
  set hostname=lille-edu-tiogapass-001
  set interface=ens9
elif [ \$net_default_mac = 00:22:4d:da:ca:87 ];
then 
  set hostname=lille-edu-capri-001
  set interface=eno1
elif [ \$net_default_mac = 00:22:4d:da:ca:a7 ];
then 
  set hostname=lille-edu-capri-002
  set inteface=eno1
else
  set hostname=
  set interface=
fi

unset timeout

menuentry 'Debian Installer (automatic install) ttyS0,57600' {
  linux /debian-installer/amd64/linux url=tftp://\$pxe_default_server/preseed.cfg vga=788 language=C country=FR keymap=fr hostname=\$hostname domain= interface=\$interface --- mitigations=off console=ttyS0,57600
  initrd /debian-installer/amd64/initrd.gz
}
menuentry 'Debian Installer (manual install) ttyS0,57600' {
  linux /debian-installer/amd64/linux vga=788 language=C country=FR keymap=fr domain= --- mitigations=off console=ttyS0,57600
  initrd /debian-installer/amd64/initrd.gz
}
menuentry 'Debian Installer (automatic install) ttyS1,57600' {
  linux /debian-installer/amd64/linux url=tftp://\$pxe_default_server/preseed.cfg vga=788 language=C country=FR keymap=fr hostname=\$hostname domain= interface=\$interface --- mitigations=off console=ttyS1,57600
  initrd /debian-installer/amd64/initrd.gz
}
menuentry 'Debian Installer (manual install) ttyS1,57600' {
  linux /debian-installer/amd64/linux vga=788 language=C country=FR keymap=fr domain= --- mitigations=off console=ttyS1,57600
  initrd /debian-installer/amd64/initrd.gz
}
menuentry 'Debian Installer (manual install) ttyS1,115200 (for Aowanda)' {
  linux /debian-installer/amd64/linux vga=788 language=C country=FR keymap=fr domain= --- mitigations=off console=ttyS1,115200
  initrd /debian-installer/amd64/initrd.gz
}
menuentry 'Ubuntu Installer (manual install) ttyS0,57600' {
  linux /ubuntu-installer/amd64/linux vga=788 language=C country=FR keymap=fr domain= --- mitigations=off console=ttyS0,57600
  initrd /ubuntu-installer/amd64/initrd.gz
}
menuentry 'SystemRescueCd' {
  linux /sysresccd/sysresccd/boot/x86_64/vmlinuz archisobasedir=sysresccd archiso_http_srv=http://\$pxe_default_server:69/sysresccd/ checksum ip=dhcp console=ttyS1,57600
  initrd /sysresccd/sysresccd/boot/intel_ucode.img /sysresccd/sysresccd/boot/amd_ucode.img /sysresccd/sysresccd/boot/x86_64/sysresccd.img
}
menuentry 'Exit' {
  exit
}
EOF
) >debian-installer/amd64/grub/grub.cfg


for hostname in lille-edu-leopard-000 lille-edu-tiogapass-001 lille-edu-capri-001 lille-edu-capri-002
do
  mkdir -p $hostname
  cat > $hostname/interfaces <<EOF
# This file describes the network interfaces available on your system
# and how to activate them. For more information, see interfaces(5).

source /etc/network/interfaces.d/*

# The loopback network interface
auto lo
iface lo inet loopback

# The primary network interface
allow-hotplug eno1
iface eno1 inet dhcp

allow-hotplug ens9
iface ens9 inet dhcp

EOF
done

exec dnsmasq -d --port=0 --log-dhcp \
  --interface=$MY_IF_NAME \
  --bind-interfaces \
  --except-interface=lo \
  --listen-address=$MY_IP_ADDR \
  --dhcp-range=$DHCP_RANGE \
  --dhcp-option=option:router,$ROUTER_ADDR \
  --dhcp-option=option:dns-server,$DNS_SERVER \
  --dhcp-boot=debian-installer/amd64/grubx64.efi \
  --enable-tftp --tftp-root=$(realpath `dirname "$0"`) \
  --conf-file=/dev/null \
  --dhcp-host=7c:fe:90:43:80:a8,192.168.46.101,1h \
  --dhcp-host=7c:fe:90:43:80:a6,192.168.46.102,1h \
  --dhcp-host=00:22:4d:da:ca:a8,192.168.46.103,1h \
  --dhcp-host=00:22:4d:da:ca:a7,192.168.46.104,1h \
  --dhcp-host=00:22:4d:da:ca:88,192.168.46.105,1h \
  --dhcp-host=00:22:4d:da:ca:87,192.168.46.106,1h \
  --dhcp-host=00:22:4d:d9:0a:ab,192.168.46.107,1h \
  --dhcp-host=00:22:4d:d9:0a:aa,192.168.46.108,1h \
  --dhcp-host=00:22:4d:da:8a:3b,192.168.46.109,1h \
  --dhcp-host=00:22:4d:da:8a:3a,192.168.46.110,1h \
  --dhcp-host=00:22:4d:da:8a:39,192.168.46.111,1h \
  --dhcp-host=00:22:4d:da:8a:38,192.168.46.112,1h \
  --dhcp-host=00:22:4d:da:5b:a1,192.168.46.113,1h \
  --dhcp-host=00:22:4d:da:5b:a0,192.168.46.114,1h \
  --dhcp-host=00:22:4d:d9:0b:bc,192.168.46.115,1h \
  --dhcp-host=00:22:4d:d9:0b:bd,192.168.46.116,1h \
  --dhcp-host=00:22:4d:da:8a:43,192.168.46.127,1h \
  --dhcp-host=00:22:4d:da:8a:42,192.168.46.128,1h \
