#!/bin/sh
set -e

SCRIPT_DIR=$(realpath `dirname "$0"`)


. $SCRIPT_DIR/download_boot_systems.sh

download_debian_11_if_needed

#UPDATE THOSE VARIABLES DEPENDING ON YOUR SITE
MY_IF_NAME=eth0
MY_IP_ADDR=192.168.46.2
DHCP_RANGE=192.168.46.100,static,255.255.255.0
ROUTER_ADDR=192.168.46.2
DNS_SERVER=8.8.8.8

(
cat <<EOF
if [ \$net_default_mac = 4c:38:d5:15:58:73 ];
then
  set hostname=netk5-aowanda-001
  set interface=eno1
elif [ \$net_default_mac = 4c:38:d5:15:58:3d ];
then 
  set hostname=netk5-aowanda-002
  set interface=eno1
elif [ \$net_default_mac = 4c:38:d5:15:58:09 ];
then 
  set hostname=netk5-aowanda-003
  set interface=eno1
else
  set hostname=
  set interface=
fi

unset timeout

menuentry 'Debian Installer (automatic install) ttyS1,115200 (for Aowanda)' {
  linux /debian-installer/amd64/linux url=tftp://\$pxe_default_server/preseed.cfg vga=788 language=C country=FR keymap=fr hostname=\$hostname domain= interface=\$interface --- mitigations=off console=ttyS1,115200
  initrd /debian-installer/amd64/initrd.gz
}
menuentry 'Debian Installer (manual install) ttyS1,115200 (for Aowanda)' {
  linux /debian-installer/amd64/linux url=tftp://\$pxe_default_server/preseed.cfg vga=788 language=C country=FR keymap=fr domain= --- mitigations=off console=ttyS1,115200
  initrd /debian-installer/amd64/initrd.gz
}
menuentry 'Exit' {
  exit
}
EOF
) >debian-installer/amd64/grub/grub.cfg


for hostname in netk5-aowanda-001 netk5-aowanda-002 netk5-aowanda-003
do
  mkdir -p $hostname
  cat > $hostname/interfaces <<EOF
# This file describes the network interfaces available on your system
# and how to activate them. For more information, see interfaces(5).

source /etc/network/interfaces.d/*

# The loopback network interface
auto lo
iface lo inet loopback

# The primary network interface
allow-hotplug ens2f0
iface ens2f0 inet dhcp

allow-hotplug ens2f1
iface ens2f1 inet dhcp

EOF
done

exec dnsmasq -d --port=0 --log-dhcp \
  --interface=$MY_IF_NAME \
  --bind-interfaces \
  --except-interface=lo \
  --listen-address=$MY_IP_ADDR \
  --dhcp-range=$DHCP_RANGE \
  --dhcp-option=option:router,$ROUTER_ADDR \
  --dhcp-option=option:dns-server,$DNS_SERVER \
  --dhcp-boot=debian-installer/amd64/grubx64.efi \
  --enable-tftp --tftp-root=$(realpath `dirname "$0"`) \
  --conf-file=/dev/null \
  --dhcp-host=4c:38:d5:15:49:d1,192.168.46.120,1h \
  --dhcp-host=4c:38:d5:15:58:74,192.168.46.121,1h \
  --dhcp-host=4c:38:d5:15:58:73,192.168.46.122,1h \
  --dhcp-host=4c:38:d5:15:58:3e,192.168.46.123,1h \
  --dhcp-host=4c:38:d5:15:58:3d,192.168.46.124,1h \
  --dhcp-host=4c:38:d5:15:58:0a,192.168.46.125,1h \
  --dhcp-host=4c:38:d5:15:58:09,192.168.46.126,1h \
